<?php
/**
 Plugin Name: Recommended Reading: Google Reader Shared
 Plugin URI: http://www.cmurrayconsulting.com/software/google-reader-shared-wordpress
 Description: Pulls shared items from your Google Reader account for display in sidebar or elsewhere. Includes sidebar widget. Easily controlled by going to "Rec. Reading" in "Settings" section. 
 Version: 1.522
 Author: Jacob M Goldman (C. Murray Consulting)
 Author URI: http://www.cmurrayconsulting.com

    Plugin: Copyright 2009 C. Murray Consulting  (email : jake@cmurrayconsulting.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


function req_check () {
  if(phpversion() < 5) {
    echo "<p>Recommended Reading plugin requires PHP 5 or newer.</p>";
    return false;
  }
}

function google_reader_shared() {

	$gr_sid = get_option("gr_sid");
	if (!$gr_sid) {
		echo "Plug-in has not been configured.";
		return false;
	}

	$url = "http://www.google.com/reader/public/atom/user%2F".$gr_sid."%2Fstate%2Fcom.google%2Fbroadcast";
	
	$ch = curl_init($url);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($ch, CURLOPT_HEADER, 0);
	$data = curl_exec($ch);
	$httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
	$content_type = substr(curl_getinfo($ch, CURLINFO_CONTENT_TYPE),5,3);
	curl_close($ch);		
	
	if ($httpcode < 200 || $httpcode >= 300 || $content_type != "xml") {
		echo "No feed found with provided ID.";
		return false;
	}
	
	$doc = new SimpleXmlElement($data, LIBXML_NOCDATA);
	
	//basic caching handling
	$feedupdate = strtotime($doc->updated);
	$lastupdate = get_option("gr_lastupdate");
	
	if($lastupdate && $lastupdate >= $feedupdate) {
		echo get_option("gr_cache");
		return true;
	}
	
	$maxcnt = get_option("gr_num");
	$cnt = count($doc->entry);
	if ($maxcnt && $maxcnt < $cnt) $cnt = $maxcnt;	//if user specified number of entries (and its less than total), here's the max loop iterations
	
	$gr_open = get_option("gr_open") ? ' target="_blank" ' : ' ';	//HTML for opening link in new window if set to	
	
	$gr_cache = '<ul>';
	for($i=0; $i<$cnt; $i++) {
		$entry = $doc->entry[$i];				
		$urlPost = $entry->link->attributes()->href;
		$title 	= $entry->title;
		
		$gr_cache = $gr_cache.'<li class="gReader-item gReader-item-'.$i.'">';
		$gr_cache = $gr_cache.'<a href="'.$urlPost.'" title="link to post"'.$gr_open.'class="gReader-title">'.$title.'</a>';
		$gr_date = get_option("gr_date");
		if ($gr_date) $gr_cache = $gr_cache.'<div class="gReader-date"><span class="preface">Published: </span>'.date($gr_date,strtotime(substr($entry->published,0,10))).'</div>';
		if (get_option("gr_source")) {
			$postsource = $entry->source->title;
			if ($postsource == "(title unknown)") $postsource = "My Shared Items";
			$gr_cache = $gr_cache.'<div class="gReader-source"><span class="preface">Source: </span><a href="'.$entry->source->link->attributes()->href.'"'.$gr_open.'title="source blog">'.$postsource.'</a></div>';	
		}
		if (get_option("gr_notes")) {
			$annotation = isset($entry->children('http://www.google.com/schemas/reader/atom/')->annotation) ? $entry->children('http://www.google.com/schemas/reader/atom/')->annotation->children()->content : "" ;
			if ($annotation) {
				$notep = get_option("gr_notep");
				if ($notep) $notep = '<span class="preface">'.$notep.' </span>';
				$gr_cache = $gr_cache.'<div class="gReader-notes">'.$notep.strip_tags($annotation).'</div>';
			}
		}
		if (get_option("gr_content")) {
			$desctrim = get_option("gr_trim");
			$desc = isset($doc->entry[$i]->content) ? $entry->content : $entry->summary;	//content may be stored in content tag or summary tag depending on blog
			
			//if (get_option("gr_hidenotes") && substr($desc,0,4) == "<blo") $desc = substr($desc, strpos($desc,"</blo"));
			if (substr($desc,0,4) == "<blo") $desc = substr($desc, strpos($desc,"</blo"));
		 	
			$desc = preg_replace('/&[^;]+;/','',strip_tags($desc));	//clean up the content removing tags and entities to avoid funny cropping
			if($desctrim && strlen($desc) > $desctrim) $desc = trim(substr($desc,0,$desctrim))."...";	//shorten content if shorter than defined max length 
			$gr_cache = $gr_cache.'<div class="gReader-desc">'.$desc.'</div>';
		}
		$gr_cache = $gr_cache.'</li>';
	}
	
	if (get_option("gr_credit")) $gr_cache = $gr_cache.'<li class="grCredit"><small>Plugin by <a href="http://www.cmurrayconsulting.com/software/google-reader-shared-wordpress/" title="Expert WordPress Developers">C. Murray Consulting</a></small></li>';
	
	$gr_cache = $gr_cache."</ul>";
	
	update_option('gr_cache',$gr_cache);
	update_option('gr_lastupdate',$feedupdate);
	
	echo $gr_cache;
	
	return true;
}

//*** WIDGET INITIALIZATION **//

function widgetGRS_control() {
	// We need to grab any preset options
	$options = get_option("setup_widget_grs");

	// No options? No problem! We set them here.
	if (!is_array( $options )) {
		$options = array(
			'title' => 'Recommended Reading'
		);
	}

	if (isset($_POST['widgetGRS-Submit'])) {
		$options['title'] = htmlspecialchars($_POST['widgetGRS-WidgetTitle']);
		// And we also update the options in the Wordpress Database
		update_option("setup_widget_grs", $options);
	}
?>
	<label for="widgetGRS-WidgetTitle">Widget Title:</label>
	<input type="text" id="widgetGRS-WidgetTitle" name="widgetGRS-WidgetTitle" value="<?php echo $options['title'];?>" />
	<input type="hidden" id="widgetGRS-Submit" name="widgetGRS-Submit" value="1" />
<?php 
	} 

function widget_grs($args) {
	extract($args);  
   
	$options = get_option("setup_widget_grs");  
  	
  	if (!is_array( $options )) {  
		$options = array(  
			'title' => 'Recommended Reading' 
		);
	}
	
	if (!$options['title']) $options['title'] = "Recommended Reading"; 
  	
	echo $before_widget;  
	echo $before_title;  
	echo $options['title'];
	echo $after_title;  
	google_reader_shared();  
	echo $after_widget;  
}

function grs_init() {
  register_sidebar_widget('Rec. Reading', 'widget_grs');
  register_widget_control('Rec Reading', 'widgetGRS_control');
}

add_action("plugins_loaded", "grs_init");


//** ADMIN CONTROL PANEL **/

function grs_admin_init() {
	add_options_page('Google Reader Shared Posts Configuration', 'Rec. Reading', 8, __FILE__, 'grs_options');
}

add_action('admin_menu', 'grs_admin_init');

//** SET DEFAULTS **/
function set_grs_options() {
	update_option('gr_credit', true);
}

register_activation_hook(__FILE__,'set_grs_options');

//** ADMIN CONTROL PANEL PAGE **//

function grs_options() { 
	update_option("gr_lastupdate",""); // clear the cache when editing the options
	?>
	<script type="text/javascript" language="javascript">
	   var http_request = false;
	   
		function isValidEmail(str) {
			return (str.lastIndexOf(".") > 2) && (str.indexOf("@") > 0) && (str.lastIndexOf(".") > (str.indexOf("@")+1)) && (str.indexOf("@") == str.lastIndexOf("@"));
		} 
	   
	   function makeRequest(idCheck) {
	   		
	   	  if (typeof idCheck == "undefined") {
	   	  	idCheck=false;	
  		  } 	  	
	   	  	
		  if (idCheck) {
		  	var gID = document.getElementById('gr_sid').value;
		  	if(gID.length != 20 || isNaN(gID)) {
		  		with (document.getElementById('message')) {
		  			innerHTML = "<p><strong>Not a valid Google ID.</strong></p>";
					style.display = "block";
				}
				with (document.getElementById('gr_sid')) {
					style.backgroundColor = '#FFCCCC';
					focus();
		  		}
		  		return false;
		  	}
		  	
		  	with (document.getElementById('message')) {
			  	innerHTML = "<p><strong>Please wait... confirming valid Google ID.</strong></p>";
				style.display = "block";
			}
		  } else {
		      var gEmail = document.getElementById('gr_un').value;
			  if(isValidEmail(gEmail) == false) {
			  	alert('Enter a valid email address used for your Google account.');
			  	docmuent.getElementById('gr_un').focus();
			  	return false;
			  }
			  
			  var gPasswd = document.getElementById('gr_pw').value;
			  if(gPasswd == "") {
			  	alert('Please enter your account password.');
			  	document.getElementById('gr_pw').focus();
			  	return false;
			  }
			  
			  with (document.getElementById('gr_sid')) {
			  	style.backgroundColor = '#FFFBCC';
			  	value = "(loading)";
	  		  }
		  }
	   	
	      http_request = false;
	      if (window.XMLHttpRequest) { // Mozilla, Safari,...
	         http_request = new XMLHttpRequest();
	         if (http_request.overrideMimeType) {
	         	// set type accordingly to anticipated content type
	            //http_request.overrideMimeType('text/xml');
	            http_request.overrideMimeType('text/html');
	         }
	      } else if (window.ActiveXObject) { // IE
	         try {
	            http_request = new ActiveXObject("Msxml2.XMLHTTP");
	         } catch (e) {
	            try {
	               http_request = new ActiveXObject("Microsoft.XMLHTTP");
	            } catch (e) {}
	         }
	      }
	      if (!http_request) {
	         alert('Cannot create XMLHTTP instance');
	         return false;
	      }
	      
	      http_request.onreadystatechange = alertContents;
	      
		  var url = "<?php bloginfo('url'); ?>/wp-content/plugins/<?php echo basename(dirname(__FILE__)); ?>/getsid.php";
		  if(idCheck) {
		  	var params = "gID="+gID;
		  } else {
		  	var params = "Email="+gEmail+"&Passwd="+gPasswd;
	  	  }
		  http_request.open("GET", url+"?"+params, true);

		  http_request.send(params);
	   }
	
	   function alertContents() {
	      if (http_request.readyState == 4) {
	         if (http_request.status == 200) {
	            //alert(http_request.responseText);
	            result = http_request.responseText;
	            if(result == "g0") {
	            	with (document.getElementById('message')) {
	            		innerHTML = "<p><strong>Google Reader ID was not valid, or you have no shared items in your feed.</strong></p>";
	            		style.display = "block";
            		}
	            	document.getElementById('gr_sid').style.backgroundColor = '#FFCCCC';
	            } else if(result == "g1") {
           			with (document.getElementById('message')) {
	            		innerHTML = "<p>Successfully validated ID!</p>";
						style.display = "block";
					}
	            	document.getElementById('gr_sid').style.backgroundColor = '#83F52C';
	            } else if(result == "0") {
           			with (document.getElementById('message')) {
	            		innerHTML = "<p><strong>Google Reader account was not found, or there was an error trying to get user account information.</strong></p>";
	            		style.display = "block";
            		}
            		with (document.getElementById('gr_sid')) {
	            		style.backgroundColor = '#FFCCCC';
	            		value = "";
            		}
	            } else {
	            	document.getElementById('message').style.display = "none";
	            	with (document.getElementById('gr_sid')) {
	            		value = result;
	            		style.backgroundColor = '#83F52C';
            		}
				}            
	         } else {
	            alert('There was a problem with the request.');
	         }
	      }
	   }
	   
	   function setMode(theMode) {
        if (typeof theMode == "undefined") {
	   	  	theMode = 1;	
  		  } 
  		  
  		  if (theMode == 1) {
  		  	with(document) {
				getElementById('gr_num').value = "5";
				getElementById('gr_content').checked = false;
	        	getElementById('gr_trim').value = "";
	        	getElementById('gr_date').value="";
	        	getElementById('gr_source').checked=false;
	        	getElementById('gr_open').checked=true;
	        	getElementById('gr_notes').checked=false;
	        	getElementById('gr_notep').value="";
	        }
          	return true;
  		  }
  		  if (theMode == 2) {
  		  	with(document) {
	      		getElementById('gr_num').value = "3";
		        getElementById('gr_content').checked = true;
		        getElementById('gr_trim').value = "210";
		        getElementById('gr_date').value="F j, Y";
		        getElementById('gr_source').checked=true;
		        getElementById('gr_open').checked=true;
		        getElementById('gr_notes').checked=true;
		        getElementById('gr_notep').value="My Note: ";
	        }
          	return true;
  		  }
	   }
	</script>


	<div class="wrap">
	<div class="icon32" style="background: transparent url(<?php bloginfo('url'); ?>/wp-content/plugins/<?php echo basename(dirname(__FILE__)); ?>/images/gr_icon.png) 3px 3px no-repeat;"><br /></div>
	<h2>Recommended Reading: Google Reader Shared Configuration</h2>
	
	<div class="updated" id="message" style="display: none;"></div>

	<div id="poststuff" style="margin-top: 20px;">
	
	<div class="postbox" style="width: 215px; min-width: 215px; float: right;">
		<h3 class="hndle">Support us</h3>
		<div class="inside">
			<p>Help support continued development of Recommended Reading and other plugins.</p>
			<p>The best thing you can do is refer someone looking for web development or strategy work <a href="http://www.cmurrayconsulting.com">to our company</a>.</p>
			<p>Short of that, here are other ways you can help:</p>
			<form method="post" action="https://www.paypal.com/cgi-bin/webscr" style="text-align: left;">
			<input type="hidden" value="_s-xclick" name="cmd"/>
			<input type="hidden" value="3377715" name="hosted_button_id"/>
			<input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif" name="submit" alt="PayPal - The safer, easier way to pay online!"/> <img height="1" border="0" width="1" alt="" src="https://www.paypal.com/en_US/i/scr/pixel.gif"/><br/>
			</form>
			<form method="post" action="options.php">
			<p><input type="checkbox" name="gr_credit" id="gr_credit"<?php if (get_option('gr_credit')) { echo ' checked="true"'; } ?> /> Include link to us [<a href="#" onclick="alert('Inserts a small link back to our site at the bottom of the output'); return false;" style="cursor: help;" title="Inserts a small link back to our site at the bottom of the output">?</a>]</p>
			<p><strong><a href="http://www.cmurrayconsulting.com/software/google-reader-shared-wordpress/">Support page</a></strong></p>
		</div>
	</div>

	
	<?php wp_nonce_field('update-options'); ?>
	
	<div class="postbox" style="width: 350px;">
		<h3 class="hndle">Required: 20 Digit Google Reader ID</h3>
		<div class="inside">
			<table class="form-table" style="clear: none;">
			<tr valign="top">
			<th scope="row">Google Reader ID</th>
			<td>
				<input type="text" name="gr_sid" id="gr_sid" value="<?php echo get_option('gr_sid'); ?>"  />
			</td>
			</tr>
			<tr valign="top">
			<th scope="row"></th>
			<td>
				<input type="button" value="Validate ID" onclick="makeRequest(1)" class="button" />
			</td>
			</tr>
			</table>
		</div>
	</div>
	
	<div class="postbox" style="width: 350px;">
		<h3 class="hndle">Optional: Find my Google Reader ID</h3>
		<div class="inside">
			<table class="form-table" style="width: auto; clear: none;">
			<tr valign="top">
			<th scope="row">Google Username</th>
			<td><input type="text" name="gr_un" id="gr_un" value="<?php echo get_option('gr_un'); ?>" /></td>
			</tr>
			<tr valign="top">
			<th scope="row">Google Password</th>
			<td><input type="password" name="gr_pw" id="gr_pw" value="<?php echo get_option('gr_pw'); ?>" /></td>
			</tr>
			<tr valign="top">
			<th scope="row"></th>
			<td>
				<input type="button" value="Get ID" onclick="makeRequest()" class="button" />
			</td>
			</tr>
			</table>
		</div>
	</div>
	
	<div class="postbox" style="width: 350px;">
		<h3 class="hndle">Display Settings</h3>
		<div class="inside">
			<table class="form-table">
			<tr valign="top">
			<th scope="row" valign="top">Quick Set</th>
			<td>
				<input type="button" value="Minimalistic" onclick="setMode(1)" class="button" />
				<input type="button" value="Detailed" onclick="setMode(2)" class="button" />
			</td>
			</tr>
			<tr valign="top">
			<th scope="row" valign="top">Number of Posts</th>
			<td>
				<input type="text" name="gr_num" id="gr_num" value="<?php echo get_option('gr_num'); ?>"  /><br />
				<span class="howto" style="line-height: 1.2em;">Leave blank or set to "0" for all.</span>
			</td>
			</tr>
			<tr valign="top">
			<th scope="row" valign="top">Show Post Content</th>
			<td style="padding-top: 10px;">
				<input type="checkbox" name="gr_content" id="gr_content"<?php if (get_option('gr_content')) { echo ' checked="true"'; } ?> />
			</td>
			</tr>
			<tr valign="top">
			<th scope="row" valign="top">Trim Post Content</th>
			<td>
				<input type="text" name="gr_trim" id="gr_trim" value="<?php echo get_option('gr_trim'); ?>"  /><br />
				<span class="howto" style="line-height: 1.2em;">Number of post characters to show. Blank or 0 = show all.</span>
			</td>
			</tr>
			<tr valign="top">
			<th scope="row" valign="top">Show Post Date</th>
			<td valign="top">
				<input type="text" name="gr_date" id="gr_date" value="<?php echo get_option('gr_date'); ?>" style="width: 80px;" />	<input type="button" value="Reset" onclick="document.getElementById('gr_date').value='F j, Y'" class="button" /><br />
				<span class="howto" style="line-height: 1.2em;">Custom PHP date format (<a href="http://php.net/date" rel="help" target="_blank">info</a>). Blank = hide date.</span>
			</td>
			</tr>
			<tr valign="top">
			<th scope="row" valign="top">Show Blog Source [<a href="#" onclick="alert('Show the name of the blog or feed this came from, with a link.'); return false;" style="cursor: help;" title="Show the name of the blog or feed this came from, with a link.">?</a>]</th>
			<td style="padding-top: 10px;">
				<input type="checkbox" name="gr_source" id="gr_source"<?php if (get_option('gr_source')) { echo ' checked="true"'; } ?> />
			</td>
			</tr>
			<tr valign="top">
			<th scope="row" valign="top">Open Links in New Window</th>
			<td style="padding-top: 10px;">
				<input type="checkbox" name="gr_open" id="gr_open"<?php if (get_option('gr_open')) { echo ' checked="true"'; } ?> />
			</td>
			</tr>
			</table>
		</div>
	</div>
	
	<div class="postbox" style="width: 350px;">
		<h3 class="hndle">Item Notes Settings</h3>
		<div class="inside">
			<table class="form-table">
				<tr valign="top">
				<th scope="row" valign="top">Show Shared Item Notes [<a href="#" onclick="alert('Google Reader lets you attach notes to shared items. This lets you display those notes. In the current version, this will not affect stand alone notes in your feed.'); return false;" style="cursor: help;" title="Google Reader lets you attach notes to shared items. This lets you display those notes. In the current version, this will not affect stand alone notes in your feed.">?</a>]</th>
				<td style="padding-top: 10px;">
					<input type="checkbox" name="gr_notes" id="gr_notes"<?php if (get_option('gr_notes')) { echo ' checked="true"'; } ?> />
				</td>
				</tr>
				<!--
				<tr valign="top">
				<th scope="row" valign="top">Hide Note in Content [<a href="#" onclick="alert('By default, Google includes any user note inline with the item content. This will remove that.'); return false;" style="cursor: help;" title="By default, Google includes any user note inline with the item's content. This will remove that.">?</a>]</th>
				<td style="padding-top: 10px;">
					<input type="checkbox" name="gr_hidenotes" id="gr_hidenotes"<?php if (get_option('gr_hidenotes')) { echo ' checked="true"'; } ?> />
				</td>
				</tr>
				-->
				<tr valign="top">
				<th scope="row" valign="top">Preface Note With [<a href="#" onclick="alert('Optional text to show before the note (i.e. My Notes)'); return false;" style="cursor: help;" title="Optional text to show before the note (i.e. My Notes)">?</a>]</th>
				<td>
					<input type="text" name="gr_notep" id="gr_notep" value="<?php echo get_option('gr_notep'); ?>" style="width: 80px;" />
				</td>
				</tr>
			</table>
		</div>
	</div>
	
	</div>
	
	<input type="hidden" name="action" value="update" />
	<input type="hidden" name="page_options" value="gr_credit,gr_sid,gr_num,gr_content,gr_trim,gr_notes,gr_date,gr_source,gr_open,gr_notep" />
	
	<p class="submit">
	<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
	</p>
	
	</form>
	</div>
  
<?php } ?>
